==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm2015/lib/WebDropdownItemDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebDropdownItemDescription } from "./WebDropdownItemDescription";
/**
 * @hidden
 */
export let WebDropdownItemDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebDropdownItemDescriptionMetadata extends Base {
        static b(a) {
            if (WebDropdownItemDescriptionMetadata.a == null) {
                WebDropdownItemDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebDropdownItemDescriptionMetadata.c(WebDropdownItemDescriptionMetadata.a);
            }
            if (a.k(WebDropdownItemDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebDropdownItemDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:DropdownItem");
            a.item("__tagNameWC", "String:igc-dropdown-item");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("Value", "String");
            a.item("Selected", "Boolean");
            a.item("Active", "Boolean");
            a.item("Disabled", "Boolean");
        }
        static d(a) {
            WebDropdownItemDescriptionMetadata.b(a);
            a.ad("WebDropdownItem", () => new WebDropdownItemDescription());
            a.ac("WebDropdownItem", WebDropdownItemDescriptionMetadata.a);
        }
    }
    WebDropdownItemDescriptionMetadata.$t = /*@__PURE__*/ markType(WebDropdownItemDescriptionMetadata, 'WebDropdownItemDescriptionMetadata');
    WebDropdownItemDescriptionMetadata.a = null;
    return WebDropdownItemDescriptionMetadata;
})();

==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm2015/lib/WebDropdownItemDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebBaseOptionLikeDescriptionMetadata } from "./WebBaseOptionLikeDescriptionMetadata";
import { WebDropdownItemDescription } from "./WebDropdownItemDescription";
/**
 * @hidden
 */
export let WebDropdownItemDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebDropdownItemDescriptionMetadata extends Base {
        static b(a) {
            if (WebDropdownItemDescriptionMetadata.a == null) {
                WebDropdownItemDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebDropdownItemDescriptionMetadata.c(WebDropdownItemDescriptionMetadata.a);
            }
            if (a.k(WebDropdownItemDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebDropdownItemDescriptionMetadata.a);
        }
        static c(a) {
            WebBaseOptionLikeDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:DropdownItem");
            a.item("__tagNameWC", "String:igc-dropdown-item");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
        }
        static d(a) {
            WebDropdownItemDescriptionMetadata.b(a);
            a.ae("WebDropdownItem", () => new WebDropdownItemDescription());
            a.ad("WebDropdownItem", WebDropdownItemDescriptionMetadata.a);
        }
    }
    WebDropdownItemDescriptionMetadata.$t = /*@__PURE__*/ markType(WebDropdownItemDescriptionMetadata, 'WebDropdownItemDescriptionMetadata');
    WebDropdownItemDescriptionMetadata.a = null;
    return WebDropdownItemDescriptionMetadata;
})();
